@@ -7,7 +7,7 @@ from render.logger import configure_logger
 from render.s3 import AWS_S3
 from render.watch.logs import collect_instance_logs
 from render.watch.screen import capture_screenshot
-from render.watch.stat import log_usage
+from render.watch.stat import log_usage, log_freq
 from render.watch.window import WindowMgr
 
 logger = logging.getLogger(__name__)
@@ -17,6 +17,7 @@ def main(args):
     s3 = AWS_S3()
     w = WindowMgr()
 
+    log_freq()
     while True:
         w.find_window_wildcard(args.window_name)
         w.foreground()
